#
# spec file for package python-Send2Trash
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-Send2Trash
Version:        1.8.3
Release:        1.3
Summary:        Python library to send files to the Trash location
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/arsenetar/send2trash
Source:         https://github.com/arsenetar/send2trash/archive/refs/tags/%{version}.tar.gz#/Send2Trash-%{version}-gh.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       typelib(GObject)
Requires:       typelib(Gio)
Requires(post): update-alternatives
Requires(postun): update-alternatives
Provides:       python-send2trash = %{version}-%{release}
BuildArch:      noarch

%python_subpackages

%description
Send2Trash is a small package that sends files to the Trash (or
Recycle Bin) natively and on all platforms. On OS X, it uses native
FSMoveObjectToTrashSync Cocoa calls, on Windows, it uses native (and
ugly) SHFileOperation win32 calls. On other platforms, if PyGObject
and GIO are available, it will use this. Otherwise, it will fallback
to its own implementation of the trash specifications from
freedesktop.org.

%prep
%setup -q -n send2trash-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/send2trash
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF8
%pytest

%post
%python_install_alternative send2trash

%postun
%python_uninstall_alternative send2trash

%files %{python_files}
%license LICENSE
%doc CHANGES.rst README.rst
%python_alternative %{_bindir}/send2trash
%{python_sitelib}/send2trash
%{python_sitelib}/Send2Trash-%{version}.dist-info

%changelog
* Wed Oct 30 2024 Dirk Müller <dmueller@suse.com>
- update to 1.8.3:
  * Add support for any iterable type as input
  * fix: Use os.fsdecode() for arguments to shutil.move()
* Sat Aug 26 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.8.2
  * Add fallback to HOMETRASH when cross device errors happen in
    plat_other (#26, #41, #63)
  * win/legacy: tiny logic simplification by @BoboTiG in #77
- PEP517
- Drop Python2 code
* Thu Aug  3 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Tue Jan  4 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.8.0
  * Add compatibility with pathlib paths (#49)
  * Fix thread compatibility of modern windows implementation (#59)
  * Fix handling of UNC names in legacy windows implementation
    (#57)
- Release Version 1.7.1
  * Fix handling of UNC names (#57)
  * Changed conditional for when to try to use pyobjc version (#51)
  * Add console_script entry point (#50)
  * Increased python CI versions (#52, #54)
  * Fix minor issue in setup.py (#53)
  * Fix issue with windows tests importing modules on non-windows
    (#55)
  * Unit test cleanups, rewrites, and flake8 cleanups
  * Windows: Fix legacy windows platform for multi-byte unicode and
    add tests
  * macOS: Add alternative pyobjc version to potentially improve
    compatibility (#51)
  * Add main method which allows calling via python -m send2trash
    somefile
  * Windows: Add support for using IFileOperation when pywin32 is
    present on Vista and newer
  * Add support for passing multiple files at once in a list
  * Windows: Batch multi-file calls to improve performance (#42)
  * Windows: Fix issue with SHFileOperation failing silently when
    path is not found (#33)
- Drop python2.patch
* Wed Mar  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.5.0:
  * More specific error when failing to create XDG fallback trash directory (#20)
  * Windows: Workaround for long paths (#23)
- Add patch to test properly under python2:
  * python2.patch
* Wed Dec 19 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary. Wrap description at 70 cols.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Oct 20 2017 toddrme2178@gmail.com
- Renamed to python-Send2Trash to follow openSUSE python package
  naming guidelines
- Implement single-spec version
- Update to Version 1.4.1
  * Fix crash on Windows introduced in v1.4.0. Oops… (#14)
- Update to Version Version 1.4.0
  * Use bytes instead of str for internal path handling in plat_other. (#13)
- Update to Version Version 1.3.1
  * Throw WindowsError instead of OSError in plat_win. (#7)
  * Fix TypeError on python 2 in plat_other. (#12)
* Fri Sep 27 2013 barendartchuk@suse.com
- created package using py2pack
